Module: BetterUi::Concerns::InlineLabelStyles

Extended by:
ActiveSupport::Concern
Included in:
BadgeComponent, TagComponent
Defined in:
app/components/better_ui/concerns/inline_label_styles.rb

Overview

Shared styling methods for inline label components (Badge, Tag).

Provides variant-aware color classes for solid, outline, soft, and ghost styles. Components including this concern must define their own STYLES constant and may override hook methods for style divergence.

Hook methods:

- outline_light_text_class: CSS class for light variant outline text
(default: "text-grayscale-400")